@@ -5,7 +5,7 @@ use Mouse;
 use Lemonldap::NG::Common::Conf::Constants;
 use Lemonldap::NG::Common::Conf::ReConstants;
 
-our $VERSION = '1.9.99_03';
+our $VERSION = '1.9.991_01';
 
 extends 'Lemonldap::NG::Common::Conf::AccessLib';
 
@@ -646,7 +646,7 @@ sub metadatas {
         return $self->sendError( $req, undef, 400 ) if ( $req->error );
         return $self->sendError( $req, "Configuration without cfgNum", 500 )
           unless ( defined $res->{cfgNum} );
-        foreach my $key (qw(cfgAuthor cfgDate cfgAuthorIP cfgLog)) {
+        foreach my $key (qw(cfgAuthor cfgDate cfgAuthorIP cfgLog cfgVersion)) {
             $res->{$key} = $self->getConfKey( $req, $key );
         }
 
