@@ -6,7 +6,7 @@ use JSON;
 use Lemonldap::NG::Common::PSGI::Constants;
 use Lemonldap::NG::Common::PSGI::Request;
 
-our $VERSION = '1.9.99_03';
+our $VERSION = '1.9.991_01';
 
 our $_json = JSON->new->allow_nonref;
 
@@ -39,13 +39,17 @@ sub init {
              $args->{logger}
           || $ENV{LLNG_DEFAULTLOGGER}
           || 'Lemonldap::NG::Common::Logger::Std';
-        eval "require $logger";
-        die $@ if ($@);
-        $self->logger( $logger->new($self) );
-        $logger = $ENV{LLNG_USERLOGGER} || $args->{userLogger} || $logger;
-        eval "require $logger";
-        die $@ if ($@);
-        $self->userLogger( $logger->new( $self, user => 1 ) );
+        unless ( $self->logger ) {
+            eval "require $logger";
+            die $@ if ($@);
+            $self->logger( $logger->new($self) );
+        }
+        unless ( $self->userLogger ) {
+            $logger = $ENV{LLNG_USERLOGGER} || $args->{userLogger} || $logger;
+            eval "require $logger";
+            die $@ if ($@);
+            $self->userLogger( $logger->new( $self, user => 1 ) );
+        }
     }
     return 1;
 }
